==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/Route53Resolver/DisassociateResolverRule.pm <==

package Paws::Route53Resolver::DisassociateResolverRule;
  use Moose;
  has ResolverRuleId => (is => 'ro', isa => 'Str', required => 1);
  has VPCId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateResolverRule');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53Resolver::DisassociateResolverRuleResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53Resolver::DisassociateResolverRule - Arguments for method DisassociateResolverRule on L<Paws::Route53Resolver>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateResolverRule on the
L<Amazon Route 53 Resolver|Paws::Route53Resolver> service. Use the attributes of this class
as arguments to method DisassociateResolverRule.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateResolverRule.

=head1 SYNOPSIS

    my $route53resolver = Paws->service('Route53Resolver');
    my $DisassociateResolverRuleResponse =
      $route53resolver->DisassociateResolverRule(
      ResolverRuleId => 'MyResourceId',
      VPCId          => 'MyResourceId',

      );

    # Results:
    my $ResolverRuleAssociation =
      $DisassociateResolverRuleResponse->ResolverRuleAssociation;

  # Returns a L<Paws::Route53Resolver::DisassociateResolverRuleResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/route53resolver/DisassociateResolverRule>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ResolverRuleId => Str

The ID of the resolver rule that you want to disassociate from the
specified VPC.



=head2 B<REQUIRED> VPCId => Str

The ID of the VPC that you want to disassociate the resolver rule from.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateResolverRule in L<Paws::Route53Resolver>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/Route53Resolver/DisassociateResolverRule.pm <==

package Paws::Route53Resolver::DisassociateResolverRule;
  use Moose;
  has ResolverRuleId => (is => 'ro', isa => 'Str', required => 1);
  has VPCId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateResolverRule');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53Resolver::DisassociateResolverRuleResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53Resolver::DisassociateResolverRule - Arguments for method DisassociateResolverRule on L<Paws::Route53Resolver>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateResolverRule on the
L<Amazon Route 53 Resolver|Paws::Route53Resolver> service. Use the attributes of this class
as arguments to method DisassociateResolverRule.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateResolverRule.

=head1 SYNOPSIS

    my $route53resolver = Paws->service('Route53Resolver');
    my $DisassociateResolverRuleResponse =
      $route53resolver->DisassociateResolverRule(
      ResolverRuleId => 'MyResourceId',
      VPCId          => 'MyResourceId',

      );

    # Results:
    my $ResolverRuleAssociation =
      $DisassociateResolverRuleResponse->ResolverRuleAssociation;

  # Returns a L<Paws::Route53Resolver::DisassociateResolverRuleResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/route53resolver/DisassociateResolverRule>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ResolverRuleId => Str

The ID of the Resolver rule that you want to disassociate from the
specified VPC.



=head2 B<REQUIRED> VPCId => Str

The ID of the VPC that you want to disassociate the Resolver rule from.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateResolverRule in L<Paws::Route53Resolver>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
